# Changelog

# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-05-18

### Added

- use of uv for project management

### Changed

- use of ruff and deptry for code checks

## [0.0.1] - 2022-12-23

### Added

- initial release
